
import React from 'react';
import { Button } from "@/components/ui/button";
import { Check } from 'lucide-react';
import { Link } from '@inertiajs/react';

const AboutSection = () => {
  const benefits = [
    "100% local guide with expert knowledge",
    "Customizable itineraries for your interests",
    "Authentic cultural experiences",
    "Support for local communities",
    "Small groups for personalized attention",
    "24/7 support throughout your journey"
  ];

  return (
    <section id="about" className="lg:py-20 md:p-12 p-6">
      <div className="container mx-auto ">
        <div className="grid grid-cols-1 lg:grid-cols-2 gap-12 items-center">
          <div className="relative">
            <div className="absolute -top-4 -left-4 w-64 h-64 bg-secondary/10 rounded-lg -z-10"></div>
            <div className="absolute -bottom-4 -right-4 w-64 h-64 bg-primary/10 rounded-lg -z-10"></div>
            <div className="grid grid-cols-2 gap-4">
              <img 
                src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcRvAiz7lmIHOXrphXvdkgSnG8cDhg7IsltLzw&s" 
                alt="Sri Lankan Tour Guide" 
                className="rounded-lg object-cover w-full h-72"
              />
              <img 
                src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcRvAiz7lmIHOXrphXvdkgSnG8cDhg7IsltLzw&s" 
                alt="Local Experience" 
                className="rounded-lg object-cover w-full h-72 mt-8"
              />
              <img 
                src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcRvAiz7lmIHOXrphXvdkgSnG8cDhg7IsltLzw&s" 
                alt="Sri Lankan Culture" 
                className="rounded-lg object-cover w-full h-72"
              />
              <img 
                src="https://encrypted-tbn0.gstatic.com/images?q=tbn:ANd9GcRvAiz7lmIHOXrphXvdkgSnG8cDhg7IsltLzw&s" 
                alt="Sri Lankan Landscape" 
                className="rounded-lg object-cover w-full h-72 mt-8"
              />
            </div>
          </div>
          
          <div>
            <h2 className="text-3xl md:text-4xl font-display font-bold mb-6 text-gray-900">
              Your Local Guide to the Wonders of Sri Lanka
            </h2>
            <p className="text-lg text-gray-600 mb-6">
              Hello! I'm Rajith, a certified tour guide with over 10 years of experience showcasing the best of my beautiful island home. I founded Ceylon Adventures with a passion for authentic travel experiences that support local communities.
            </p>
            <p className="text-lg text-gray-600 mb-8">
              My tours are designed to take you beyond the typical tourist path. Whether you're interested in ancient history, wildlife, stunning landscapes, or immersing yourself in our vibrant culture, I'll create an unforgettable journey tailored to your interests.
            </p>
            
            <div className="grid grid-cols-1 md:grid-cols-2 gap-3 mb-8">
              {benefits.map((benefit, index) => (
                <div key={index} className="flex items-center">
                  <Check className="text-secondary mr-2 flex-shrink-0" />
                  <span className="text-gray-700">{benefit}</span>
                </div>
              ))}
            </div>
            
            <Button size="lg" className="rounded-full px-8">
              <Link href='/about'>Learn More About Me</Link>
            </Button>
          </div>
        </div>
      </div>
    </section>
  );
};

export default AboutSection;
